/*
** License Applicability. Except to the extent portions of this file are
** made subject to an alternative license as permitted in the SGI Free
** Software License B, Version 1.1 (the "License"), the contents of this
** file are subject only to the provisions of the License. You may not use
** this file except in compliance with the License. You may obtain a copy
** of the License at Silicon Graphics, Inc., attn: Legal Services, 1600
** Amphitheatre Parkway, Mountain View, CA 94043-1351, or at:
** 
** http://oss.sgi.com/projects/FreeB
** 
** Note that, as provided in the License, the Software is distributed on an
** "AS IS" basis, with ALL EXPRESS AND IMPLIED WARRANTIES AND CONDITIONS
** DISCLAIMED, INCLUDING, WITHOUT LIMITATION, ANY IMPLIED WARRANTIES AND
** CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY, FITNESS FOR A
** PARTICULAR PURPOSE, AND NON-INFRINGEMENT.
** 
** Original Code. The Original Code is: OpenGL Sample Implementation,
** Version 1.2.1, released January 26, 2000, developed by Silicon Graphics,
** Inc. The Original Code is Copyright (c) 1991-2000 Silicon Graphics, Inc.
** Copyright in any portions created by third parties is as indicated
** elsewhere herein. All Rights Reserved.
** 
** Additional Notice Provisions: The application programming interfaces
** established by SGI in conjunction with the Original Code are The
** OpenGL(R) Graphics System: A Specification (Version 1.2.1), released
** April 1, 1999; The OpenGL(R) Graphics System Utility Library (Version
** 1.3), released November 4, 1998; and OpenGL(R) Graphics with the X
** Window System(R) (Version 1.3), released October 19, 1998. This software
** was created using the OpenGL(R) version 1.2.1 Sample Implementation
** published by SGI, but has not been independently verified as being
** compliant with the OpenGL(R) version 1.2.1 Specification.
**
*/

#ifdef HAVE_DIX_CONFIG_H
#include <dix-config.h>
#endif

#include "glxserver.h"
#include "g_disptab_EXT.h"

__GLXrenderSizeData __glXRenderSizeTable[__GLX_MAX_RENDER_OPCODE_EXT - __GLX_MIN_RENDER_OPCODE_EXT + 1] = {
	/* no such opcode      */       {   0,  0                         },
	/* CallList            */	{   8, 	0                         },
	/* CallLists           */	{  12, 	__glXCallListsReqSize     },
	/* ListBase            */	{   8, 	0                         },
	/* Begin               */	{   8, 	0                         },
	/* Bitmap              */	{  48, 	__glXBitmapReqSize        },
	/* Color3bv            */	{   8, 	0                         },
	/* Color3dv            */	{  28, 	0                         },
	/* Color3fv            */	{  16, 	0                         },
	/* Color3iv            */	{  16, 	0                         },
	/* Color3sv            */	{  12, 	0                         },
	/* Color3ubv           */	{   8, 	0                         },
	/* Color3uiv           */	{  16, 	0                         },
	/* Color3usv           */	{  12, 	0                         },
	/* Color4bv            */	{   8, 	0                         },
	/* Color4dv            */	{  36, 	0                         },
	/* Color4fv            */	{  20, 	0                         },
	/* Color4iv            */	{  20, 	0                         },
	/* Color4sv            */	{  12, 	0                         },
	/* Color4ubv           */	{   8, 	0                         },
	/* Color4uiv           */	{  20, 	0                         },
	/* Color4usv           */	{  12, 	0                         },
	/* EdgeFlagv           */	{   8, 	0                         },
	/* End                 */	{   4, 	0                         },
	/* Indexdv             */	{  12, 	0                         },
	/* Indexfv             */	{   8, 	0                         },
	/* Indexiv             */	{   8, 	0                         },
	/* Indexsv             */	{   8, 	0                         },
	/* Normal3bv           */	{   8, 	0                         },
	/* Normal3dv           */	{  28, 	0                         },
	/* Normal3fv           */	{  16, 	0                         },
	/* Normal3iv           */	{  16, 	0                         },
	/* Normal3sv           */	{  12, 	0                         },
	/* RasterPos2dv        */	{  20, 	0                         },
	/* RasterPos2fv        */	{  12, 	0                         },
	/* RasterPos2iv        */	{  12, 	0                         },
	/* RasterPos2sv        */	{   8, 	0                         },
	/* RasterPos3dv        */	{  28, 	0                         },
	/* RasterPos3fv        */	{  16, 	0                         },
	/* RasterPos3iv        */	{  16, 	0                         },
	/* RasterPos3sv        */	{  12, 	0                         },
	/* RasterPos4dv        */	{  36, 	0                         },
	/* RasterPos4fv        */	{  20, 	0                         },
	/* RasterPos4iv        */	{  20, 	0                         },
	/* RasterPos4sv        */	{  12, 	0                         },
	/* Rectdv              */	{  36, 	0                         },
	/* Rectfv              */	{  20, 	0                         },
	/* Rectiv              */	{  20, 	0                         },
	/* Rectsv              */	{  12, 	0                         },
	/* TexCoord1dv         */	{  12, 	0                         },
	/* TexCoord1fv         */	{   8, 	0                         },
	/* TexCoord1iv         */	{   8, 	0                         },
	/* TexCoord1sv         */	{   8, 	0                         },
	/* TexCoord2dv         */	{  20, 	0                         },
	/* TexCoord2fv         */	{  12, 	0                         },
	/* TexCoord2iv         */	{  12, 	0                         },
	/* TexCoord2sv         */	{   8, 	0                         },
	/* TexCoord3dv         */	{  28, 	0                         },
	/* TexCoord3fv         */	{  16, 	0                         },
	/* TexCoord3iv         */	{  16, 	0                         },
	/* TexCoord3sv         */	{  12, 	0                         },
	/* TexCoord4dv         */	{  36, 	0                         },
	/* TexCoord4fv         */	{  20, 	0                         },
	/* TexCoord4iv         */	{  20, 	0                         },
	/* TexCoord4sv         */	{  12, 	0                         },
	/* Vertex2dv           */	{  20, 	0                         },
	/* Vertex2fv           */	{  12, 	0                         },
	/* Vertex2iv           */	{  12, 	0                         },
	/* Vertex2sv           */	{   8, 	0                         },
	/* Vertex3dv           */	{  28, 	0                         },
	/* Vertex3fv           */	{  16, 	0                         },
	/* Vertex3iv           */	{  16, 	0                         },
	/* Vertex3sv           */	{  12, 	0                         },
	/* Vertex4dv           */	{  36, 	0                         },
	/* Vertex4fv           */	{  20, 	0                         },
	/* Vertex4iv           */	{  20, 	0                         },
	/* Vertex4sv           */	{  12, 	0                         },
	/* ClipPlane           */	{  40, 	0                         },
	/* ColorMaterial       */	{  12, 	0                         },
	/* CullFace            */	{   8, 	0                         },
	/* Fogf                */	{  12, 	0                         },
	/* Fogfv               */	{   8, 	__glXFogfvReqSize         },
	/* Fogi                */	{  12, 	0                         },
	/* Fogiv               */	{   8, 	__glXFogivReqSize         },
	/* FrontFace           */	{   8, 	0                         },
	/* Hint                */	{  12, 	0                         },
	/* Lightf              */	{  16, 	0                         },
	/* Lightfv             */	{  12, 	__glXLightfvReqSize       },
	/* Lighti              */	{  16, 	0                         },
	/* Lightiv             */	{  12, 	__glXLightivReqSize       },
	/* LightModelf         */	{  12, 	0                         },
	/* LightModelfv        */	{   8, 	__glXLightModelfvReqSize  },
	/* LightModeli         */	{  12, 	0                         },
	/* LightModeliv        */	{   8, 	__glXLightModelivReqSize  },
	/* LineStipple         */	{  12, 	0                         },
	/* LineWidth           */	{   8, 	0                         },
	/* Materialf           */	{  16, 	0                         },
	/* Materialfv          */	{  12, 	__glXMaterialfvReqSize    },
	/* Materiali           */	{  16, 	0                         },
	/* Materialiv          */	{  12, 	__glXMaterialivReqSize    },
	/* PointSize           */	{   8, 	0                         },
	/* PolygonMode         */	{  12, 	0                         },
	/* PolygonStipple      */	{ 152, 	0                         },
	/* Scissor             */	{  20, 	0                         },
	/* ShadeModel          */	{   8, 	0                         },
	/* TexParameterf       */	{  16, 	0                         },
	/* TexParameterfv      */	{  12, 	__glXTexParameterfvReqSize },
	/* TexParameteri       */	{  16, 	0                         },
	/* TexParameteriv      */	{  12, 	__glXTexParameterivReqSize },
	/* TexImage1D          */	{  56, 	__glXTexImage1DReqSize    },
	/* TexImage2D          */	{  56, 	__glXTexImage2DReqSize    },
	/* TexEnvf             */	{  16, 	0                         },
	/* TexEnvfv            */	{  12, 	__glXTexEnvfvReqSize      },
	/* TexEnvi             */	{  16, 	0                         },
	/* TexEnviv            */	{  12, 	__glXTexEnvivReqSize      },
	/* TexGend             */	{  20, 	0                         },
	/* TexGendv            */	{  12, 	__glXTexGendvReqSize      },
	/* TexGenf             */	{  16, 	0                         },
	/* TexGenfv            */	{  12, 	__glXTexGenfvReqSize      },
	/* TexGeni             */	{  16, 	0                         },
	/* TexGeniv            */	{  12, 	__glXTexGenivReqSize      },
	/* InitNames           */	{   4, 	0                         },
	/* LoadName            */	{   8, 	0                         },
	/* PassThrough         */	{   8, 	0                         },
	/* PopName             */	{   4, 	0                         },
	/* PushName            */	{   8, 	0                         },
	/* DrawBuffer          */	{   8, 	0                         },
	/* Clear               */	{   8, 	0                         },
	/* ClearAccum          */	{  20, 	0                         },
	/* ClearIndex          */	{   8, 	0                         },
	/* ClearColor          */	{  20, 	0                         },
	/* ClearStencil        */	{   8, 	0                         },
	/* ClearDepth          */	{  12, 	0                         },
	/* StencilMask         */	{   8, 	0                         },
	/* ColorMask           */	{   8, 	0                         },
	/* DepthMask           */	{   8, 	0                         },
	/* IndexMask           */	{   8, 	0                         },
	/* Accum               */	{  12, 	0                         },
	/* Disable             */	{   8, 	0                         },
	/* Enable              */	{   8, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* PopAttrib           */	{   4, 	0                         },
	/* PushAttrib          */	{   8, 	0                         },
	/* Map1d               */	{  28, 	__glXMap1dReqSize         },
	/* Map1f               */	{  20, 	__glXMap1fReqSize         },
	/* Map2d               */	{  48, 	__glXMap2dReqSize         },
	/* Map2f               */	{  32, 	__glXMap2fReqSize         },
	/* MapGrid1d           */	{  24, 	0                         },
	/* MapGrid1f           */	{  16, 	0                         },
	/* MapGrid2d           */	{  44, 	0                         },
	/* MapGrid2f           */	{  28, 	0                         },
	/* EvalCoord1dv        */	{  12, 	0                         },
	/* EvalCoord1fv        */	{   8, 	0                         },
	/* EvalCoord2dv        */	{  20, 	0                         },
	/* EvalCoord2fv        */	{  12, 	0                         },
	/* EvalMesh1           */	{  16, 	0                         },
	/* EvalPoint1          */	{   8, 	0                         },
	/* EvalMesh2           */	{  24, 	0                         },
	/* EvalPoint2          */	{  12, 	0                         },
	/* AlphaFunc           */	{  12, 	0                         },
	/* BlendFunc           */	{  12, 	0                         },
	/* LogicOp             */	{   8, 	0                         },
	/* StencilFunc         */	{  16, 	0                         },
	/* StencilOp           */	{  16, 	0                         },
	/* DepthFunc           */	{   8, 	0                         },
	/* PixelZoom           */	{  12, 	0                         },
	/* PixelTransferf      */	{  12, 	0                         },
	/* PixelTransferi      */	{  12, 	0                         },
	/* PixelMapfv          */	{  12, 	__glXPixelMapfvReqSize    },
	/* PixelMapuiv         */	{  12, 	__glXPixelMapuivReqSize   },
	/* PixelMapusv         */	{  12, 	__glXPixelMapusvReqSize   },
	/* ReadBuffer          */	{   8, 	0                         },
	/* CopyPixels          */	{  24, 	0                         },
	/* DrawPixels          */	{  40, 	__glXDrawPixelsReqSize    },
	/* DepthRange          */	{  20, 	0                         },
	/* Frustum             */	{  52, 	0                         },
	/* LoadIdentity        */	{   4, 	0                         },
	/* LoadMatrixf         */	{  68, 	0                         },
	/* LoadMatrixd         */	{ 132, 	0                         },
	/* MatrixMode          */	{   8, 	0                         },
	/* MultMatrixf         */	{  68, 	0                         },
	/* MultMatrixd         */	{ 132, 	0                         },
	/* Ortho               */	{  52, 	0                         },
	/* PopMatrix           */	{   4, 	0                         },
	/* PushMatrix          */	{   4, 	0                         },
	/* Rotated             */	{  36, 	0                         },
	/* Rotatef             */	{  20, 	0                         },
	/* Scaled              */	{  28, 	0                         },
	/* Scalef              */	{  16, 	0                         },
	/* Translated          */	{  28, 	0                         },
	/* Translatef          */	{  16, 	0                         },
	/* Viewport            */	{  20, 	0                         },
	/* PolygonOffset       */	{  12, 	0                         },
	/* DrawArrays          */	{  16, 	__glXDrawArraysSize       },
	/* Indexubv            */	{  8, 	0                         },
	/* ColorSubTable       */       {  44,  __glXColorSubTableReqSize },
	/* CopyColorSubTable   */       {  24,  0                         },
	/* ActiveTextureARB    */       {  8,   0                         },
	/* MultiTexCoord1dvARB */       {  16,  0                         },
	/* MultiTexCoord1fvARB */       {  12,  0                         },
	/* MultiTexCoord1ivARB */       {  12,  0                         },
	/* MultiTexCoord1svARB */       {  12,  0                         },
	/* MultiTexCoord2dvARB */       {  24,  0                         },
	/* MultiTexCoord2fvARB */       {  16,  0                         },
	/* MultiTexCoord2ivARB */       {  16,  0                         },
	/* MultiTexCoord2svARB */       {  12,  0                         },
	/* MultiTexCoord3dvARB */       {  32,  0                         },
	/* MultiTexCoord3fvARB */       {  20,  0                         },
	/* MultiTexCoord3ivARB */       {  20,  0                         },
	/* MultiTexCoord3svARB */       {  16,  0                         },
	/* MultiTexCoord4dvARB */       {  40,  0                         },
	/* MultiTexCoord4fvARB */       {  24,  0                         },
	/* MultiTexCoord4ivARB */       {  24,  0                         },
	/* MultiTexCoord4svARB   213 */ {  16,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode        220 */ {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* WindowPos3fARB        230 */ {  16,  0                         },
};
__GLXrenderSizeData __glXRenderSizeTable_EXT[__GLX_MAX_RENDER_OPCODE_EXT - __GLX_MIN_RENDER_OPCODE_EXT + 1] = {
	/* ColorTable          2053 */  {  44,  __glXColorTableReqSize    },
	/* ColorTableParameterfv */     {  12,  __glXColorTableParameterfvReqSize         },
	/* ColorTableParameteriv */     {  12,  __glXColorTableParameterivReqSize         },
	/* CopyColorTable      */       {  24,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* PointParameterfARB   2065 */ {  12,  0                         },
	/* PointParameterfvARB  2066 */ {   8,  __glXPointParameterfvARBReqSize },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */       {   0,  0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* BlendColor          */       {  20,  0                         },
	/* BlendEquation       */       {   8,  0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* TexSubImage1D       */       {  60,  __glXTexSubImage1DReqSize },
	/* TexSubImage2D       */       {  60,  __glXTexSubImage2DReqSize },
	/* ConvolutionFilter1D */       {  48,  __glXConvolutionFilter1DReqSize },
	/* ConvolutionFilter2D     */   {  48,  __glXConvolutionFilter2DReqSize },
	/* ConvolutionParameterf   */   {  16,  0                         },
	/* ConvolutionParameterfv  */   {  12,  __glXConvolutionParameterfvReqSize },
	/* ConvolutionParameteri   */   {  16,  0                         },
	/* ConvolutionParameteriv  */   {  12,  __glXConvolutionParameterivReqSize },
	/* CopyConvolutionFilter1D */   {  24,                            },
	/* CopyConvolutionFilter2D */   {  28,                            },
	/* SeparableFilter2D   */       {  48,  __glXSeparableFilter2DReqSize },
	/* Histogram           */       {  20,                            },
	/* Minmax              */       {  16,                            },
	/* ResetHistogram      */       {  8,                             },
	/* ResetMinmax         */       {  8,                             },
	/* TexImage3D          */       {  84,  __glXTexImage3DReqSize    },
	/* TexSubImage3D       */       {  92,  __glXTexSubImage3DReqSize },
	/* DrawArrays          */	{  16, 	__glXDrawArraysSize       },
	/* BindTexture         */	{  12, 	0                         },
	/* PrioritizeTextures  */	{   8, 	__glXPrioritizeTexturesReqSize },
	/* CopyTexImage1D      */	{  32, 	0 },
	/* CopyTexImage2D      */	{  36, 	0 },
	/* CopyTexSubImage1D   */	{  28, 	0 },
	/* CopyTexSubImage2D   */	{  36, 	0 },
	/* CopyTexSubImage3D    4123 */ {  40,  0 },
	/* FogCoordfv           4124 */	{   8, 	0 },
	/* FogCoorddv           4125 */	{  12, 	0 },
	/* SecondaryColor3bv    4126 */	{   8, 	0 },
	/* SecondaryColor3sv    4127 */	{  12, 	0 },
	/* SecondaryColor3iv    4128 */	{  16, 	0 },
	/* SecondaryColor3fv    4129 */	{  16, 	0 },
	/* SecondaryColor3dv    4130 */	{  28, 	0 },
	/* SecondaryColor3ubv   4131 */	{   8, 	0 },
	/* SecondaryColor3usv   4132 */	{  12, 	0 },
	/* SecondaryColor3uiv   4133 */	{  16, 	0 },
	/* BlendFuncSeparate    4134 */	{  20, 	0 },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* no such opcode      */	{   0, 	0                         },
	/* ActiveStencilFaceEXT 4220 */ {   8,  0 },
	/* PointParameteri      4221 */	{  12, 	0 },
	/* PointParameteriv     4222 */	{   8, 	__glXPointParameterivReqSize },
};
